@@ -1,18 +1,19 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 3 of the License, or
+// This file is part of GNU ucommon.
+//
+// GNU ucommon is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ucommon is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
-// GNU General Public License for more details.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ucommon.  If not, see <http://www.gnu.org/licenses/>.
 
 /**
  * Private heaps, pools, and associations.
@@ -130,6 +131,15 @@ public:
 	 */
 	virtual void *alloc(size_t size);
 
+	/**
+	 * Allocate memory from the pager heap.  The size of the request must be
+	 * less than the size of the memory page used.  The memory is initialized
+	 * to zero.
+	 * @param size of memory request.
+	 * @return allocated memory or NULL if not possible.
+	 */
+	void *zalloc(size_t size);
+
 	/**
 	 * Duplicate NULL terminated string into allocated memory.
 	 * @param string to copy into memory.
@@ -233,6 +243,16 @@ public:
 	 */
 	void *alloc(size_t size);
 
+	/**
+	 * Allocate memory from the pager heap.  The size of the request must be
+	 * less than the size of the memory page used.  The memory pager mutex
+	 * is locked during this operation and then released.  This version
+	 * zeros memory after the mutex lock has been released.
+	 * @param size of memory request.
+	 * @return allocated memory or NULL if not possible.
+	 */
+	void *zalloc(size_t size);
+
 	/**
 	 * Duplicate NULL terminated string into allocated memory.  The mutex
 	 * lock is acquired to perform this operation and then released.
